# Armed Services Board of Contract Appeals

## Published Decisions - 2014

Decision Date | ASBCA Number | Appellant/Petitioner | Judge
August |  |  |
August 28, 2014 | 59021, 59022, 59023, 59024, 59192, 59264 | Direct Project, Inc. | Delman
August 28, 2014 | 59079, 59080 | Suffolk Construction Company | Newsom
August 26, 2014 | 58610 | ARINC Inc. | Stempler
August 26, 2014 | 59197 | Quimba Software, Inc. | Stempler
August 26, 2014 | 59196 | Quimba Software, Inc. | Stempler
August 22, 2014 | 58586 | TransWest Manufacturing, LLC | Page
August 21, 2014 | 59109 | Nodak Electric Power Cooperative, Inc. and Cavalier Rural Electric Cooperative, Inc., JV | Stempler
August 21, 2014 | 59117 | Binghamton Simulator Company | Melnick
August 21, 2014 | 59356 | Grunley/Goel JV, LLC | Stempler
August 19, 2014 | 56839 | Family Entertainment Services, Inc. D/B/A/ IMC | Page
August 19, 2014 | 58507 | SERDI, LLC | Tunks
August 19, 2014 | 59319 | QuarterLine Consulting Services, LLC | Tunks
August 18, 2014 | 58492 | Kellogg Brown & Root Services, Inc. | Younger
August 18, 2014 | 58577 | Grounds Maintenance, Inc. | Dickinson
August 18, 2014 | 58747 | GSC Construction, Inc. | Peacock
August 18, 2014 | 56711 | Macro-Z Technology | James
August 18, 2014 | 59454-948 | Jaynes Corporation | Stempler
August 13, 2014 | 58343 | Environmental Safety Consultants, Inc. | Freeman
August 13, 2014 | 59253 | McGoldrick Construction Services Corporation | Dickinson
August 13, 2014 | 59205 | Bizhan Niazi Logistic Services Company | O'Sullivan
August 12, 2014 | 58355, 59008 | CCIE & Co. | Melnick
August 12, 2014 | 56584 | Hanley Industries, Inc. | Paul
August 13, 2014 | 57206 | Gilbane Building Company | James
August 11, 2014 | 59339 | M&H Enterprises, Inc. | Stempler
August 11, 2014 | 58698, 58699, 58700, 58701, 58702, 58703, 58704, 58705, 58706, 58707, 58708, 58709, 58710, 58711, 58712, 58713, 58714, 58715, 58716, 58717, 58718, 58719, 58720, 58721, 58722, 58723, 58724 | James W. Ancel, Inc. | Stempler
August 11, 2014 | 58605, 58615 | Santa Barbara Infrared, Inc. | Stempler
August 11, 2014 | 58357 | L-3 Communications Corporation | Stempler
August 7, 2014 | 59254 | Commissioning Solutions Global, LLC | Lopes
August 7, 2014 | 59206 | Abdul Ahad Khadim Construction Company | Lopes
August 7, 2014 | 58584 | Synkera Technologies, Inc. | Ting
August 6, 2014 | 56142, 56251 | AEON Group, LLC | Dickinson
August 6 ,2014 | 59067 | Pros Cleaners | Lopes
August 6, 2014 | 58386 | Alpine Diversified, Inc. | Peacock
August 5, 2014 | 59077 | Northrop Grumman Corporation | Stempler
August 4, 2014 | 57266 | Distributed Solutions, Inc. | Clarke
August 4, 2014 | 58416 | Al Bahar Company | Mcilmail
August 1, 2014 | 58214, 58215, 58216, 59231 | Integrity Management Services, Inc. | Younger
August 1, 2014 | 59032 | PHA-JMR JV | James
August 1, 2014 | 59295 | W.J. Electric, LLC | Stempler
July |  |  |
July 29, 2014 | 57521, 57522 | Lockheed Martin Maritime Systems & Sensors | Stempler
July 29, 2014 | 58063 | Delta Engineering, Inc. | Peacock
July 29, 2014 | 58340 | American Ordnance LLC | Dickinson
July 29, 2014 | 58447, 59010 | Al-Muntakaa Company | Tunks
July 29, 2014 | 58561, 58562, 58563, 58566, 58567 | Linc Government Services, LLC | James
July 29, 2014 | 58726, 58795 | Polu Kai Services, LLC | Paul
July 29, 2014 | 59292 | Fluor Corporation | Stempler
July 25, 2014 | 58343 | Environmental Safety Consultants, Inc. | Freeman
July 25, 2014 | 57814, 57964 | PBS&J Constructors, Inc. | Scott
July 24, 2014 | 57812 | Trident Security Devices, Inc. | O'Connell
July 23, 2014 | 58873 | Raytheon Technical Services Company, LLC | Melnick
July 23, 2014 | 59041 | Lee's Ford Dock, Inc. | Clarke
July 22, 2014 | 58023 | MIC/CCS, Joint Venture | Scott
July 22, 2014 | 57746, 58252 | DODS, Inc. | Peacock
July 21, 2014 | 58587 | The Boeing Company | Wilson
July 21, 2014 | 58315, 58316, 58317, 58318, 58319, 58320, 58549 | ECC-RMA, LLC | Delman
July 18, 2014 | 58578 | Kellogg Brown & Root Services, Inc. | Younger
July 18, 2014 | 58347, 58348, 58445, 58618 | Metag Insaat Ticaret, A.S. | Hartman
July 17, 2014 | 59204 | Allison Transmission, Inc. | Delman
July 17, 2014 | 58914 | The Boeing Company | Stempler
July 17, 2014 | 58758 | Lockheed Martin Services, Inc. | Stempler
July 15, 2014 | 58810 | BAE Systems San Francisco Ship Repair | Ting
July 15, 2014 | 59379 | SSI Technology, Inc. | Stempler
July 15, 2014 | 59346 | Dominion Virginia Power | Williams
July 11, 2014 | 59318-946 | SoCo-Piedmont J.V., LLC | Stempler
July 10, 2014 | 59342 | Zalzar FZE | Stempler
July 10, 2014 | 59341 | Zalzar FZE | Stempler
July 10, 2014 | 59340 | Zalzar FZE | Stempler
July 10, 2014 | 58375,58572 | Classic Site Solutions, Inc. | Clarke
July 9, 2014 | 58858,58859,58860 | The Boeing Company | Stempler
July 9, 2014 | 59181 | Iron Bow Technologies, LLC | Mcilmail
July 9, 2014 | 58909 | Lockheed Martin Corporation | Stempler
July 8, 2014 | 58782 | Certified Construction Company of Kentucky, LLC | Ting
July 7, 2014 | 57148,57149,57599 | Al Barih for General Contracting Ltd. | Paul
July 3, 2014 | 59143, 59279 | Progressive Construction Company, LLC | Thrasher
July 3, 2014 | 59004 | POZ Engineering and Environmental Consulting | Tunks
July 2, 2014 | 59321 | Restaurants Hawaii, LLC | Stempler
July 2, 2014 | 59163 | CB&I Federal Services LLC | Stempler
July 1, 2014 | 59161 | Family Entertainment Services, Inc. D/B/A IMC | Freeman
July 1, 2014 | 59271 | Axxon International, LLC | Scott
July 1, 2014 | 59127 | Creek Services, LLC | Tunks
June |  |  |
June 27, 2014 | 58232 | Forrester Construction Company | Hartman
June 27, 2014 | 58983 | Forrester Construction Company | Hartman
June 26, 2014 | 58376, 58573 | Classic Site Solutions, Inc. | Clarke
June 26, 2014 | 59033 | Day & Zimmermann Hawthorne Corporation | Stempler
June 26, 2014 | 58352 | Automotive Management Services | Delman
June 25, 2014 | 59012 | Benetech, LLC | Stempler
June 24, 2014 | 59217 | The Boeing Company | Stempler
June 23, 2014 | 58919, 58920 | Exelis Systems Corporation | Stempler
June 19, 2014 | 58809 | BAE Systems San Francisco Ship Repair | Ting
June 19, 2014 | 57831 | Caddell Construction Co., Inc. | Page
June 19, 2014 | 57313 | Tzell Airtrak Travel Group Corporation | Tunks
June 19, 2014 | 57286 | TMS Envirocon, Inc. | James
June 17, 2014 | 59062 | Fluor Intercontinental, Inc. | Peacock
June 17, 2014 | 58815 | Dynamics Research Corporation | Peacock
June 17, 2014 | 58596, 58597 | DSE, Inc. | Stempler
June 17, 2014 | 56358, 57151, 57327, 58559 | Kellogg Brown & Root Services, Inc. | Freeman
June 13, 2014 | 57513, 57514 | Sigma Group International | Scott
June 12, 2014 | 58778 | New Iraq Ahd Company | Dickinson
June 12, 2014 | 59174 | Landmark Skate and Fun LLC | Clarke
June 11, 2014 | 58928 | The Timken Company | Stempler
June 11, 2014 | 56578 | Bruce E. Zoeller | Delman
June 10, 2014 | 59065 | Zomord Company | James
June 10, 2014 | 58656, 58657 | Facility Site Contractors, Inc. | Clarke
June 9, 2014 | 59125 | AL Wahej Al Lamea Company | Stempler
June 9, 2014 | 59072 | Tasty Snow LLC | Stempler
June 9, 2014 | 58969 | Glad's Original BBQ Express, LLC | Stempler
June 9, 2014 | 58953 | Patriot Pride Jewelry, LLC | Peacock
June 9, 2014 | 58580, 58691 | Superior Maritime Services, Inc. and Pacific Maritime Freight, Inc. (d/b/a Pacific Tugboat Service) Co-Venture | Peacock
June 9, 2014 | 58129 | Tele-Consultants, Inc. | Melnick
June 6, 2014 | 59076 | Leidos, Inc., f/k/a Science Applications International Corporation | Melnick
June 6, 2014 | 58997 | ERSM (Afghanistan) Limited, d/b/a Edinburgh International | Paul
June 6, 2014 | 59198 | L-3 Communications Link Simulation & Training | Stempler
June 3, 2014 | 59179 | International Promotional Ideas Inc. | Stempler
May |  |  |
May 29, 2014 | 58569 | Laguna Construction Company, Inc. | Delman
May 28, 2014 | 59112 | Triton Systems, Inc. | Stempler
May 28, 2014 | 57611 | DayDanyon Corporation | James
May 23, 2014 | 56447, 57719 | Troy Eagle Group | Wilson
May 21, 2014 | 58985 | Jaynes Corporation | Tunks
May 14, 2014 | 58242 | MIC/CCS, Joint Venture | Scott
May 13, 2014 | 58853, 59004 | POZ Engineering and Environmental Consulting | Tunks
May 13, 2014 | 58457 | C.R. Pittman Construction Company, Inc. | Peacock
May 13, 2014 | 58541, 58542, 58544, 58545 | Guzar Mirbachakot Transportation | Stempler
May 12, 2014 | 58517 | The R.R. Gregory Corporation | James
May 8, 2014 | 57638 | RLB Contracting, Inc. | Thrasher
May 8, 2014 | 58200, 58201, 58202, 58203 | Tresco, Inc. | Ting
May 7, 2014 | 58589 | Didlake, Inc. | Hartman
May 7, 2014 | 58956 | The Boeing Company | Stempler
May 7, 2014 | 58987 | Lockheed Martin Corporation | Stempler
May 7, 2014 | 58384 | Teddy's Cool Treats | Tunks
May 7, 2014 | 57378 | Sacramento Weed & Growth Regulators, Inc. | Delman
May 6, 2014 | 59006 | ATK Space Systems, Inc. | Stempler
May 5, 2014 | 58671 | Ensign-Bickford Aerospace & Defense Company | Thrasher
May 2, 2014 | 58278 | Environmental Tectonics Corporation | Williams
May 1, 2014 | 58970 | Touchstone Research Laboratory, Ltd. | Stempler
April |  |  |
April 30, 2014 | 58898 | University of Louisville Research Foundation, Inc. | Stempler
April 29, 2014 | 59056 | EMTA Insaat A.S. | James
April 29, 2014 | 57940, 57941 | Hewlett-Packard Company | Thrasher
April 29, 2104 | 58800 | New Iraq Ahd Company | Stempler
April 28, 2014 | 58760 | Suh'dutsing Technologies, LLC | Delman
April 25, 2014 | 58857 | Balfour Beatty/McCarthy, Joint Venture | Stempler
April 25, 2014 | 58667, 58695, 58839 | Delta Industries, Inc. | Clarke
April 25, 2014 | 57491, 57492 | International Oil Trading Company | Freeman
April 24, 2014 | 59173 | Beechcraft Defense Company | Stempler
April 24, 2014 | 58792, 58793 | S&L Enterprise, Inc. | Melnick
April 23, 2014 | 59059 | Tokyo Company | Ting
April 23, 2014 | 58941 | TJC Engineering, Inc. | Stempler
April 23, 2014 | 58779 | Maersk Line Limited, Inc. | Peacock
April 23, 2014 | 58632 | Zara Company | Melnick
April 23, 2014 | 58251, 58305 | Three Bullets, Inc. | Melnick
April 23, 2014 | 56758 | American General Trading & Contracting, WLL | Melnick
April 21, 2014 | 57280 | Joe Phillips | Scott
April 18, 2014 | 59178 | Lobar, Inc. | Stempler
April 17, 2014 | 58827, 58828 | Puget Sound Environmental Corp. | James
April 17, 2014 | 59152 | Lucius A. Gilliam | Stempler
April 15, 2014 | 59185 | Defense Support Services LLC | Stempler
April 15, 2014 | 58733 | Duncan Aviation, Inc. | Tunks
April 11, 2014 | 59074 | Dyno Group, Inc. | Melnick
April 11, 2014 | 58879 | LinQuest Corporation | Stempler
April 10, 2014 | 58078 | Public Warehousing Company K.S.C. | Ting
April 8, 2014 | 59011 | Technologists Inc. | Stempler
April 8, 2014 | 59068 | Notation Supply Services | Stempler
April 8, 2014 | 58196 | Moore's Cafeteria Services, Ltd. | Stempler
April 4, 2014 | 59014 | Thefaf Al-Rafidain Contracting Co. | James
April 4, 2014 | 58425 | Esood Al Blad Company | Tunks
April 4, 2014 | 57852 | Fluor Corporation | Peacock
April 4, 2014 | 57750 | A-1 Horton's Moving Service, Inc. | Tunks
April 1, 2014 | 58759 | Coast/ACM | Stempler
April 1, 2014 | 58556, 58557 | Eyak Services, LLC | Melnick
April 1, 2014 | 58552, 58553, 58554, 58555 | Eyak Technology, LLC | Melnick
April 1, 2014 | 59140 | G. A. Richards & Co., Inc. | Stempler
March |  |  |
March 27, 2014 | 57891, 57892, 57893, 57894, 58189, 58193 | HTA Aviation, LLC | Page
March 27, 2014 | 58026, 58750 | World Rose Company | Thrasher
March 26, 2014 | 58801 | Taj Al Rajaa Company | James
March 26, 2014 | 58560 | Linc Government Services, LLC | James
March 25, 2014 | 59130 | Solpac Construction Inc., dba Soltek Pacific Construction Company | Stempler
March 25, 2014 | 58751 | Rentfrow Inc. | Stempler
March 25, 2014 | 58631 | Environmental Chemical Corporation | Stempler
March 25, 2014 | 58246, 58247, 58248 | IPICOM, Inc., dba IPITEK | Stempler
March 24, 2014 | 58235 | Singleton Enterprises | Clarke
March 24, 2014 | 58968 | Magwood Services, Inc. | Scott
March 19, 2014 | 58693 | The Boeing Company | Stempler
March 19, 2014 | 58019, 58021, 58470, 58471, 58472, 58473, 58878 | PKD, Inc. | Ting
March 18, 2014 | 58063 | Delta Engineering, Inc. | Peacock
March 18, 2014 | 58332 | Mylene Will Company LLC | Younger
March 14, 2014 | 57316 | CCI, Inc. | Scott
March 13, 2014 | 59124 | Ohana Industries, Ltd. | Page
March 13, 2014 | 58984 | Kellogg Brown & Root Services, Inc. | Stempler
March 13, 2014 | 58926 | Kellogg Brown & Root Services, Inc. | Stempler
March 13, 2014 | 58661 | Kellogg Brown & Root Services, Inc. | Stempler
March 13, 2014 | 58655 | Angel Menendez Environmental Services, Inc. | Scott
March 12, 2014 | 58353 | Sadaf Petroleum Kabul, Ltd. | Tunks
March 11, 2014 | 59015 | United Terex | Stempler
March 11, 2014 | 58802, 58803 | Stanley Associates, Inc. | Stempler
March 11, 2014 | 58797, 58798, 59083, 59084 | Mayflower Communications Company, Inc. | Stempler
March 11, 2014 | 58665 | Advanced Technology Logistics, Inc. | Stempler
March 11, 2014 | 57735 | Abkarr Corporation | Page
March 6, 2014 | 58419 | Analex Corporation | Scott
March 6, 2014 | 58072 | Applied Technical Systems, Inc. | Grant
March 5, 2014 | 56257, 56337 | CI², Inc. | Delman
March 5, 2014 | 58804 | Fluor Corporation | Stempler
March 5, 2014 | 58624 | Green Jacket Contractors, LLC | Stempler
March 4, 2014 | 58692 | Gerald R. Rouillard III dba International Gear Technologies | Thrasher
March 4, 2014 | 58869 | Exelis Inc., Information Systems Division | Stempler
February |  |  |
February 27, 2014 | 58961 | Thorpe Seeop Corporation | Stempler
February 26, 2014 | 58846 | Reagan Construction Corporation | Stempler
February 25, 2014 | 58295, 58296, 58297, 58298, 58299, 58387, 58388, 58389, 58390 | Skanska USA Building, Inc. | Ting
February 25, 2014 | 59061 | Naher Al-Jabil Company | Stempler
February 20, 2014 | 58937, 58938 | Exelis Inc., Information Systems Division | Stempler
February 19, 2014 | 57811 | West Point Apparel Group, Inc. | Stempler
February 19, 2014 | 59018 | Towers Hawks Iraq Company For General Contracting Ltd. | Stempler
February 12, 2014 | 59075 | Guam Industrial Services, Inc., d/b/a Guam Shipyard | Stempler
February 12, 2014 | 58362 | Golden Bay Construction Company | Stempler
February 12, 2014 | 58449 | Geosan Gae Jun Co., Ltd. | Stempler
February 12, 2014 | 58461 | Jayco International, LLC | Clarke
February 12, 2014 | 59137 | Leidos, Inc., f/k/a Science Applications International Corporation | Stempler
February 11, 2014 | 57047, 57278, 57399 | Washington Group/Alberici Joint Venture | Paul
February 11, 2014 | 58826 | Siemens Goverment Technologies, Inc. | Stempler
February 11, 2014 | 58120, 58219 | Washington Security Group, Inc. | Shackleford
February 10, 2014 | 58645 | FRASSON LODOVICO S.r.l. | Shackleford
February 7, 2014 | 59086 | Looks Great Services, Inc. | Stempler
February 6, 2014 | 58517 | The R.R. Gregory Corporation | James
February 6, 2014 | 59013 | Mongiovi & Son | Stempler
February 5, 2014 | 58801 | Taj Al Rajaa Company | James
February 5, 2014 | 58764 | QSS Group, Inc. | Stempler
February 5, 2014 | 59007-945 | Commissioning Solutions Global, LLC | Stempler
February 5, 2014 | 58523, 58524, 58525, 58526, 58527, 58528, 58529, 58530 | Pulliam Construction Company, Inc. | Stempler
February 4, 2014 | 58675 | Jaynes Corporation | Clarke
January |  |  |
January 30, 2014 | 58314 | EJB Facilities Services | Younger
January 29, 2014 | 59131 | Autonomous Solutions, Inc. | Stempler
January 29, 2014 | 58851 | Pathfinder Systems, Inc. | Stempler
January 29, 2014 | 58533 | CP of Bozeman, Inc., dba Maintenance Patrol | Clarke
January 29, 2014 | 57853 | Tower One Construction Co. | Scott
January 28, 2014 | 51722 | Environmental Safety Consultants, Inc. | Freeman
January 28, 2014 | 57406 | Bulova Technologies Ordnance Systems LLC | Grant
January 28, 2014 | 58746 | Violet Dock Port, Inc., LLC | Stempler
January 27, 2014 | 58006 | CAE USA, Inc. | Clarke
January 24, 2014 | 58393 | Hensel Phelps Construction Company | Younger
January 23, 2014 | 56572 | G & C Enterprises, Inc. | Lane
January 23, 2014 | 55358 | ADT Construction Group, Inc. by Timothy S. Cory, Chapter 7 Trustee | Shackleford
January 23, 2014 | 57095, 57166 | Safety Training Systems, Inc. | Shackleford
January 23, 2014 | 58847 | Environmental Safety Consultants, Inc. | Freeman
January 22, 2014 | 58513 | Kellogg Brown & Root Services, Inc. | Stempler
January 22, 2014 | 57611, 57681, 57717 | DayDanyon Corporation | James
January 17, 2014 | 58950 | Dawson-Alamol JV, LLC | Stempler
January 16, 2014 | 57625 | Northrop Grumman Corporation | Delman
January 15, 2014 | 58595 | DooleyMack Constructors | Stempler
January 15, 2014 | 58308 | Daniel S. Sinclair, Callan E. Sinclair & Cayman C. Sinclair | Peacock
January 15, 2014 | 58198 | Hanley Industries, Inc. | Melnick
January 14, 2014 | 57796, 57888 | Garco Construction, Inc. | Clarke
January 13, 2014 | 58307, 58805 | Pratt & Whitney Rocketdyne, Inc. | Scott
January 9, 2014 | 58499, 58500, 58501, 58502, 58503, 58504, 58505, 58506 | Shaw Environmental & Infrastructure, Inc. | Ting
January 9, 2014 | 58540 | Baco Epik Metis, JV | Melnick
January 9, 2014 | 58368 | D. L. Withers Construction, LC | Stempler
January 8, 2014 | 57783, 57909 | NOVA Technology Corporation | James
January 7, 2014 | 58590 | Balad Alshemal Earth Company | Stempler
January 7, 2014 | 58668, 58772 | All Star Technical Services, Inc. | Thrasher
January 6, 2014 | 58636 | Teledyne Brown Engineering, Inc. | Younger
January 3, 2014 | 57638 | RLB Contracting, Inc. | Thrasher
January 2, 2014 | 58769, 58897 | Compusearch Software Systems, Inc. | Stempler
January 2, 2014 | 58757 | Lockheed Martin Corporation | Stempler
January 2, 2014 | 58670 | Stephens Construction and Concrete, Inc. | Grant

### Additional Information

### Decisions